@@ -1,6 +1,3 @@
-# Author:  Lisandro Dalcin
-# Contact: dalcinl@gmail.com
-
 # -----------------------------------------------------------------------------
 
 """
@@ -21,7 +18,7 @@ a large, sparse, rectangular matrix.
 """
 
 __author__  = 'Lisandro Dalcin'
-__version__ = '3.22.2'
+__version__ = '3.24.0'
 __credits__ = 'SLEPc Team <slepc-maint@upv.es>'
 
 # -----------------------------------------------------------------------------
@@ -32,7 +29,7 @@ def init(args=None, arch=None):
 
     :Parameters:
       - `args`: command-line arguments, usually the 'sys.argv' list.
-      - `arch`: specific configuration to use.
+      - ``arch``: specific configuration to use.
 
     .. note:: This function should be called only once, typically at
        the very beginning of the bootstrap script of an application.
